guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

branch master updated: ci: Restrict substitute search to guix jobset.


From: guix-commits
Subject: branch master updated: ci: Restrict substitute search to guix jobset.
Date: Sun, 19 Dec 2021 10:25:59 -0500

This is an automated email from the git hooks/post-receive script.

mothacehe pushed a commit to branch master
in repository guix.

The following commit(s) were added to refs/heads/master by this push:
     new 11334d1  ci: Restrict substitute search to guix jobset.
11334d1 is described below

commit 11334d15d590073c631c574436d2110aa1ea2142
Author: Andrew Whatson <whatson@gmail.com>
AuthorDate: Sun Dec 19 16:24:01 2021 +0100

    ci: Restrict substitute search to guix jobset.
    
    * guix/ci.scm (latest-builds): Add jobset keyword.
    (find-latest-commit-with-substitutes): Pass jobset "guix".
    
    Signed-off-by: Mathieu Othacehe <othacehe@gnu.org>
---
 guix/ci.scm | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/guix/ci.scm b/guix/ci.scm
index 01b493b..88b80f7 100644
--- a/guix/ci.scm
+++ b/guix/ci.scm
@@ -208,7 +208,7 @@ api-agnostic."
     (map json->build (vector->list queue))))
 
 (define* (latest-builds url #:optional (limit %query-limit)
                         #:key evaluation system job status)
   "Return the latest builds performed by the CI server at URL.  If EVALUATION
 is an integer, restrict to builds of EVALUATION.  If SYSTEM is true (a system
 string such as \"x86_64-linux\"), restrict to builds for SYSTEM."
@@ -218,6 +218,7 @@ string such as \"x86_64-linux\"), restrict to builds for 
SYSTEM."
                  `("evaluation" ,evaluation)
                  `("system" ,system)
                  `("job" ,job)
+                 `("jobset" ,jobset)
                  `("status" ,status))))
     ;; Note: Hydra does not provide a "derivation" field for entries in
     ;; 'latestbuilds', but Cuirass does.
@@ -286,6 +287,7 @@ definitions at URL.  Return false if no commit were found."
   (let* ((job-name (string-append "guix." (%current-system)))
          (build (match (latest-builds url 1
                                       #:job job-name
+                                      #:jobset "guix"
                                       #:status 0) ;success
                   ((build) build)
                   (_ #f)))
@@ -208,7 +208,7 @@ api-agnostic."
 
 (define* (latest-builds url #:optional (limit %query-limit)
-                        #:key evaluation system job status)
+                        #:key evaluation system job jobset status)
   "Return the latest builds performed by the CI server at URL.  If EVALUATION
 is an integer, restrict to builds of EVALUATION.  If SYSTEM is true (a system



reply via email to

[Prev in Thread] Current Thread [Next in Thread]